@@ -5,12 +5,12 @@ use strict;
 use Apache::Session;
 use Apache::Session::Lock::Null;
 use Apache::Session::Browseable::Store::LDAP;
-use Apache::Session::Generate::SHA256;
-use Apache::Session::Serialize::JSON;
+use Apache::Session::Generate::MD5;
+use Apache::Session::Serialize::Base64;
 use Apache::Session::Browseable::_common;
 use Net::LDAP::Util qw(escape_filter_value);
 
-our $VERSION = '1.3.6';
+our $VERSION = '1.1';
 our @ISA     = qw(Apache::Session Apache::Session::Browseable::_common);
 
 sub populate {
@@ -18,10 +18,10 @@ sub populate {
 
     $self->{object_store} = new Apache::Session::Browseable::Store::LDAP $self;
     $self->{lock_manager} = new Apache::Session::Lock::Null $self;
-    $self->{generate}     = \&Apache::Session::Generate::SHA256::generate;
-    $self->{validate}     = \&Apache::Session::Generate::SHA256::validate;
-    $self->{serialize}    = \&Apache::Session::Serialize::JSON::serialize;
-    $self->{unserialize}  = \&Apache::Session::Serialize::JSON::unserialize;
+    $self->{generate}     = \&Apache::Session::Generate::MD5::generate;
+    $self->{validate}     = \&Apache::Session::Generate::MD5::validate;
+    $self->{serialize}    = \&Apache::Session::Serialize::Base64::serialize;
+    $self->{unserialize}  = \&Apache::Session::Serialize::Base64::unserialize;
 
     return $self;
 }
@@ -29,7 +29,7 @@ sub populate {
 sub unserialize {
     my $session = shift;
     my $tmp = { serialized => $session };
-    Apache::Session::Serialize::JSON::unserialize($tmp);
+    Apache::Session::Serialize::Base64::unserialize($tmp);
     return $tmp->{data};
 }
 
@@ -84,7 +84,6 @@ sub _query {
     );
 
     $ldap->unbind();
-    $ldap->disconnect();
 
     if ( $msg->code ) {
         Apache::Session::Browseable::Store::LDAP->logError($msg);
@@ -181,8 +180,6 @@ Apache::Session::Browseable::LDAP - An implementation of Apache::Session::LDAP
     ldapAttributeId      => 'cn',
     ldapAttributeContent => 'description',
     ldapAttributeIndex   => 'ou',
-    ldapVerify           => 'require',
-    ldapCAFile           => '/etc/ssl/certs/ca-certificates.crt',
   };
 
 =head1 DESCRIPTION
@@ -190,23 +187,16 @@ Apache::Session::Browseable::LDAP - An implementation of Apache::Session::LDAP
 This module is an implementation of Apache::Session. It uses an LDAP directory
 to store datas.
 
+=head1 AUTHOR
+
+Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
 =head1 COPYRIGHT AND LICENSE
 
 =encoding utf8
 
-=over
-
-=item 2009-2025 by Xavier Guimard
-
-=item 2013-2025 by Clément Oudot
-
-=item 2019-2025 by Maxime Besson
-
-=item 2013-2025 by Worteks
-
-=item 2023-2025 by Linagora
-
-=back
+Copyright (C) 2009 by Xavier Guimard
+Copyright (C) 2013, 2015 by Clement Oudot
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
