@@ -5,11 +5,11 @@ use strict;
 use Apache::Session;
 use Apache::Session::Lock::Null;
 use Apache::Session::Browseable::Store::MySQL;
-use Apache::Session::Generate::SHA256;
-use Apache::Session::Serialize::JSON;
+use Apache::Session::Generate::MD5;
+use Apache::Session::Serialize::Storable;
 use Apache::Session::Browseable::DBI;
 
-our $VERSION = '1.2.5';
+our $VERSION = '0.9';
 our @ISA     = qw(Apache::Session::Browseable::DBI Apache::Session);
 
 sub populate {
@@ -17,21 +17,16 @@ sub populate {
 
     $self->{object_store} = new Apache::Session::Browseable::Store::MySQL $self;
     $self->{lock_manager} = new Apache::Session::Lock::Null $self;
-    $self->{generate}     = \&Apache::Session::Generate::SHA256::generate;
-    $self->{validate}     = \&Apache::Session::Generate::SHA256::validate;
-    $self->{serialize}    = \&Apache::Session::Serialize::JSON::serialize;
-    $self->{unserialize}  = \&Apache::Session::Serialize::JSON::unserialize;
+    $self->{generate}     = \&Apache::Session::Generate::MD5::generate;
+    $self->{validate}     = \&Apache::Session::Generate::MD5::validate;
+    $self->{serialize}    = \&Apache::Session::Serialize::Storable::serialize;
+    $self->{unserialize}  = \&Apache::Session::Serialize::Storable::unserialize;
 
     return $self;
 }
 
-# Override default CAST syntax from DBI.pm
-sub _buildLowerThanExpression {
-    my ( $class, $field, $value ) = @_;
-    return "CAST($field AS SIGNED INTEGER) < $value";
-}
-
 1;
+
 __END__
 
 =head1 NAME
@@ -41,26 +36,6 @@ Apache::Session::MySQL
 
 =head1 SYNOPSIS
 
-Create table with columns for indexed fields. Example for Lemonldap::NG:
-
-  CREATE TABLE sessions (
-      id varchar(64) not null primary key,
-      a_session text,
-      _whatToTrace text,
-      _session_kind text,
-      _utime bigint,
-      ipAddr text
-  );
-
-Add indexes:
-
-  CREATE INDEX uid1 ON sessions (_whatToTrace) USING BTREE;
-  CREATE INDEX s1   ON sessions (_session_kind);
-  CREATE INDEX u1   ON sessions (_utime);
-  CREATE INDEX ip1  ON sessions (ipAddr) USING BTREE;
-
-Use it with Perl:
-
   use Apache::Session::Browseable::MySQL;
 
   my $args = {
@@ -121,23 +96,16 @@ sessions and add the capability to index some fields to make research faster.
 
 L<Apache::Session>
 
+=head1 AUTHOR
+
+Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
 =head1 COPYRIGHT AND LICENSE
 
 =encoding utf8
 
-=over
-
-=item 2009-2023 by Xavier Guimard
-
-=item 2013-2023 by Clément Oudot
-
-=item 2019-2023 by Maxime Besson
-
-=item 2013-2023 by Worteks
-
-=item 2023 by Linagora
-
-=back
+Copyright (C) 2009-2013 by Xavier Guimard
+              2013 by Clément Oudot
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.1 or,
