@@ -7,13 +7,7 @@ use Apache::Session::Store::MySQL;
 
 our @ISA =
   qw(Apache::Session::Browseable::Store::DBI Apache::Session::Store::MySQL);
-our $VERSION = '1.2.2';
-
-sub connection {
-    my($self,$session)=@_;
-    $self->SUPER::connection($session);
-    $self->{dbh}->{mysql_enable_utf8} = 1;
-}
+our $VERSION = '0.1';
 
 1;
 
